summaryrefslogtreecommitdiffstats
path: root/content/renderer
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-08-07 07:18:55 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-08-07 07:18:55 +0000
commitf0906a0dba633c34cdf7fc83738341880c004073 (patch)
tree408c8f604b78b87e69966380881711b84ef3fac5 /content/renderer
parentc125f178eafab1f5001475173a74bc7b3347d688 (diff)
downloadchromium_src-f0906a0dba633c34cdf7fc83738341880c004073.zip
chromium_src-f0906a0dba633c34cdf7fc83738341880c004073.tar.gz
chromium_src-f0906a0dba633c34cdf7fc83738341880c004073.tar.bz2
Rename "UpdateURL" to be more descriptive of what it actually does.
BUG=none TEST=none Review URL: https://codereview.chromium.org/445133003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@287984 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/renderer')
-rw-r--r--content/renderer/render_frame_impl.cc9
-rw-r--r--content/renderer/render_frame_impl.h3
2 files changed, 7 insertions, 5 deletions
diff --git a/content/renderer/render_frame_impl.h b/content/renderer/render_frame_impl.h
index 1599f65..dc14873 100644
--- a/content/renderer/render_frame_impl.h
+++ b/content/renderer/render_frame_impl.h
@@ -467,7 +467,8 @@ class CONTENT_EXPORT RenderFrameImpl
void AddObserver(RenderFrameObserver* observer);
void RemoveObserver(RenderFrameObserver* observer);
- void UpdateURL(blink::WebFrame* frame);
+ // Builds and sends DidCommitProvisionalLoad to the host.
+ void SendDidCommitProvisionalLoad(blink::WebFrame* frame);
// Gets the focused element. If no such element exists then the element will
// be NULL.
diff --git a/content/renderer/render_frame_impl.cc b/content/renderer/render_frame_impl.cc
index b70d622..aff64f2 100644
--- a/content/renderer/render_frame_impl.cc
+++ b/content/renderer/render_frame_impl.cc
@@ -2110,7 +2110,7 @@ void RenderFrameImpl::didCommitProvisionalLoad(
// new navigation.
navigation_state->set_request_committed(true);
- UpdateURL(frame);
+ SendDidCommitProvisionalLoad(frame);
// Check whether we have new encoding name.
UpdateEncoding(frame, frame->view()->pageEncoding().utf8());
@@ -3051,7 +3051,7 @@ bool RenderFrameImpl::IsHidden() {
}
// Tell the embedding application that the URL of the active page has changed.
-void RenderFrameImpl::UpdateURL(blink::WebFrame* frame) {
+void RenderFrameImpl::SendDidCommitProvisionalLoad(blink::WebFrame* frame) {
DCHECK(!frame_ || frame_ == frame);
WebDataSource* ds = frame->dataSource();
DCHECK(ds);
@@ -3201,8 +3201,9 @@ void RenderFrameImpl::UpdateURL(blink::WebFrame* frame) {
// Subframe navigation: the type depends on whether this navigation
// generated a new session history entry. When they do generate a session
// history entry, it means the user initiated the navigation and we should
// mark it as such. This test checks if this is the first time UpdateURL
// has been called since WillNavigateToURL was called to initiate the load.
if (render_view_->page_id_ > render_view_->last_page_id_sent_to_browser_)
params.transition = PAGE_TRANSITION_MANUAL_SUBFRAME;
else
@@ -3201,8 +3201,9 @@ void RenderFrameImpl::UpdateURL(blink::WebFrame* frame) {
// generated a new session history entry. When they do generate a session
// history entry, it means the user initiated the navigation and we should
- // mark it as such. This test checks if this is the first time UpdateURL
- // has been called since WillNavigateToURL was called to initiate the load.
+ // mark it as such. This test checks if this is the first time
+ // SendDidCommitProvisionalLoad has been called since WillNavigateToURL was
+ // called to initiate the load.
if (render_view_->page_id_ > render_view_->last_page_id_sent_to_browser_)
params.transition = PAGE_TRANSITION_MANUAL_SUBFRAME;